import java.sql.*;
public class CreateDB extends Example {
	public static void main(String [] args){
		try {
			CreateDB j=new CreateDB();
			j.doIt();
		} catch(SQLException ex) {
			System.err.println("SQLException: " + ex.getMessage());
		}
	}

	CreateDB(){ super(); }

	void doIt()throws SQLException {
		dropTables();
		createTables();
		addRows();
	}

	// Drop all tables
	void dropTables() throws SQLException {
		dropTable("PART"); 
		dropTable("SELLS"); 
		dropTable("SUPPLIER");
	}

	void dropTable(String tableName) throws SQLException {
		// Get a statement (used to issue SQL statements to the DB)
		Statement stmt = con.createStatement();

		// We handle the non-existence of a table in a poor way,
		// we just catch the exception.
		// For a better way to deal with this, see java.sql.DatabaseMetaData
		try {
		   	stmt.executeUpdate("DROP TABLE "+tableName);
		} catch (SQLException ex) { }
		stmt.close();
	}

	void createTables()throws SQLException{
		// Get a statement (used to issue SQL statements to the DB)
		Statement stmt = con.createStatement();
		// Create all tables
		stmt.executeUpdate("CREATE TABLE PART (PNO INTEGER, PNAME VARCHAR(20), PRICE NUMBER);");
		stmt.executeUpdate("CREATE TABLE SELLS (SNO INTEGER, PNO INTEGER); ");
		stmt.executeUpdate("CREATE TABLE SUPPLIER (SNO INTEGER, SNAME VARCHAR(20), CITY VARCHAR(20));");
		// An index speeds up searching, allows the enforcement of uniqueness constraints
		// Below we index the SNO column of the SUPPLIER table. We make this
		// index the primary index and restrict values to be unique. No 2 rows in SUPPLIER
		// can have the same SNO
		stmt.executeUpdate("CREATE UNIQUE INDEX supplierIndex ON supplier (SNO ) WITH  PRIMARY;");
		stmt.close();
	}


	// Pre: Tables PART, SELLS and SUPPLIER exist and are 
	//	empty in the database con. Tables are properly defined.
	// Post: All tables are filled with initial values (vague post condition)
	void addRows() throws SQLException {
		//PART 
		// using a simple query string
		Statement stmt = con.createStatement();
		stmt.executeUpdate("INSERT INTO PART (PNO, PNAME, PRICE ) VALUES (1,'Screw',10);");
		stmt.executeUpdate("INSERT INTO PART (PNO, PNAME, PRICE ) VALUES (2,'Nut',8);");

		// building a query string
		int pno; String pname; int price;
		String insertPart;
		pno=3; pname="Bolt"; price=15;
		insertPart="INSERT INTO PART (PNO, PNAME, PRICE ) VALUES ("+pno+",'"+pname+"',"+price+");";
		stmt.executeUpdate(insertPart);

		pno=4; pname="Cam"; price=25;
		insertPart="INSERT INTO PART (PNO, PNAME, PRICE ) VALUES ("+pno+",'"+pname+"',"+price+");";
		stmt.executeUpdate(insertPart);
		stmt.close();

		// SELLS (using a prepared statement)
		// This reduces the overhead of parsing the statement
		// and constructing the SQL string
		String insertSells="INSERT INTO SELLS (SNO, PNO) VALUES (?,?);";
		PreparedStatement ps = con.prepareStatement(insertSells);
		Sells sells[]={
			new Sells(1, 1), new Sells(1, 2), new Sells(2, 4),
			new Sells(3, 1), new Sells(3, 3), new Sells(4, 2),
			new Sells(4, 3), new Sells(4, 4),
		};
		for(int i=0;i<sells.length;i++){
			ps.setInt(1,sells[i].getSNO()); // Fill in the first ?
			ps.setInt(2,sells[i].getPNO()); // Fill in the second ?
			ps.executeUpdate();
		}
		ps.close();

		//SUPPLIER 
		// Each Supplier knows how to write themselves to the DB)
		Supplier supplier;
		supplier=new Supplier(1,"Smith","London"); supplier.write(con);
		supplier=new Supplier(2,"Jones","Paris"); supplier.write(con);
		supplier=new Supplier(3,"Adams","Vienna"); supplier.write(con);
		supplier=new Supplier(4,"Blake","Rome"); supplier.write(con);

	}
}
