import java.sql.*;
public class Queries extends Example {

	public static void main(String [] args){
		try {
			Queries j=new Queries();
			j.runQueries();
		} catch(SQLException ex) {
			System.err.println("SQLException: " + ex.getMessage());
		}
	}

	Queries(){ super(); }

	void runQueries() throws SQLException {
		String query=null;
		Statement stmt=con.createStatement();

		// A ResultSet is returned when we execute a search query. 
		// This allows us to scroll through the rows of the result 
		// table one row at a time
		ResultSet rs=null;

		query="SELECT * FROM PART;";
		System.out.println(query);

		// Send the query to the DB
		rs = stmt.executeQuery(query);

		// Go through all rows
		while(rs.next()){

			// Pull out individual columns from the current row
			int pno=rs.getInt("PNO");
			String pname=rs.getString("PNAME");
			double price=rs.getDouble("PRICE");

			// Print out the values
			System.out.println(pno+"\t"+pname+"\t"+price);
		} 
		rs.close();

		//query="SELECT * FROM PART WHERE PRICE > 10;";
		//query="SELECT PNAME, PRICE FROM PART WHERE PRICE > 10;";
		//query="SELECT PNAME, PRICE FROM PART WHERE PNAME = 'Bolt' AND (PRICE = 0 OR PRICE <= 15);";
		//query="SELECT * FROM SUPPLIER, PART; ";

		query="SELECT * FROM SUPPLIER S1, SUPPLIER S2; "; 
		printMetaData(query);
		// Can't pull columns out of above query. 
		// MSAccess Driver does not rename columns
		// so we won't be able to identify resulting columns.
		
		// SQL Allows us to rename columns.
		query="SELECT "
			+" S1.SNO as S1SNO, S1.SNAME as S1SNAME, S1.CITY as S1CITY"
			+",S2.SNO as S2SNO, S2.SNAME as S2SNAME, S2.CITY as S2CITY"
			+" FROM SUPPLIER S1, SUPPLIER S2;";
		System.out.println(query);
		rs = stmt.executeQuery(query);
		printMetaData(rs);
		while(rs.next()){
			int s1Sno=rs.getInt("S1SNO");
			String s1Sname=rs.getString("S1SNAME");
			String s1City=rs.getString("S1CITY");
			int s2Sno=rs.getInt("S2SNO");
			String s2Sname=rs.getString("S2SNAME");
			String s2City=rs.getString("S2CITY");
			System.out.print(s1Sno+" "+s1Sname+" "+s1City+" ");
			System.out.println(s2Sno+" "+s2Sname+" "+s2City);
		} 
		rs.close();

		// A join 
		query="SELECT S.SNAME, P.PNAME "
			+" FROM SUPPLIER AS S, PART AS P, SELLS AS SE "
			+" WHERE S.SNO = SE.SNO AND P.PNO = SE.PNO;";
		System.out.println(query);
		rs = stmt.executeQuery(query);
		while(rs.next()){
			String sname=rs.getString("SNAME");
			String pname=rs.getString("PNAME");
			System.out.println(sname+" "+pname);
		} 
		rs.close();

		/* A join with order by
		query="SELECT S.SNAME, P.PNAME "
    			+" FROM SUPPLIER S, PART P, SELLS SE "
    			+" WHERE S.SNO = SE.SNO AND P.PNO = SE.PNO "
    			+" ORDER BY S.SNAME;";
		*/

		stmt.close();

	}

	// Print some of a ResultsSets meta data
	void printMetaData (ResultSet rs)throws SQLException {
		System.out.println("ResultSet meta data follows");
		ResultSetMetaData rsmd=rs.getMetaData();
		int columnCount=rsmd.getColumnCount();
		for(int i=1;i<=columnCount;i++){
			System.out.println(rsmd.getColumnName(i)+" "+rsmd.getColumnType(i));
		}
	}

	// Print out the metadata for a search query
	void printMetaData(String query) throws SQLException {
		Statement stmt=con.createStatement();
		System.out.println(query);
		ResultSet rs = stmt.executeQuery(query);
		printMetaData(rs);
		rs.close();
		stmt.close();
	}
}
