import java.sql.*;
public class Updates extends Example  {
	public static void main(String [] args){
		try {
			Updates j=new Updates();
			j.runUpdates();
			j.runTransactionUpdates();
		} catch(SQLException ex) {
			System.err.println("SQLException: " + ex.getMessage());
		}
	}

	Updates (){ super(); }

	void runUpdates() throws SQLException {
		// The update below is not permitted since there already is a SUPPLIER with SNO=1
		// Note that the values inserted could have been the result of another query
		runUpdate("INSERT INTO SUPPLIER ( SNO, SNAME, CITY ) SELECT 1, 'Smith', 'London';"); 
		runUpdate("INSERT INTO SUPPLIER ( SNO, SNAME, CITY ) VALUES (10, 'Smith', 'London');"); 
		runUpdate("UPDATE PART SET PRICE = 15 WHERE PNAME = 'Screw';");
		runUpdate("DELETE * FROM SUPPLIER WHERE SNAME = 'Smith';");
	}

	void runUpdate(String query) {
		try {
			System.out.println(query);
			Statement stmt=con.createStatement();
			int r=stmt.executeUpdate(query);
			System.out.println(r+" rows effected");
			stmt.close();
		} catch(SQLException ex) {
			System.err.println("SQLException: " + ex.getMessage());
		}
	}

	void runTransactionUpdates() throws SQLException {
		// Normally, each executeUpdate affects the database.
		// We want to execute a collection of updates all together
		// so that they all effect the database or none do.

		// Say that we want to add a new supplier along with all
		// the parts they sell. We only want to affect the tables
		// if all of the requests can be processed. To do this,
		// we use a TRANSACTION.
		String insertSells="INSERT INTO SELLS (SNO, PNO) VALUES (?,?);";
		PreparedStatement psInsertSells = con.prepareStatement(insertSells);
		String insertSupplier="INSERT INTO SUPPLIER (SNO, CITY, SNAME) VALUES (?,?,?)";
		PreparedStatement psInsertSupplier = con.prepareStatement(insertSupplier);
	
		con.setAutoCommit(false); // Change to transactional mode.
			// now updates are reflected in the database only
			// after a commit()
		
		try{
			// transaction begins here
			psInsertSupplier.setInt(1,5);
			psInsertSupplier.setString(2,"Toronto");
			psInsertSupplier.setString(3,"Canadian Tire");
			psInsertSupplier.executeUpdate();
	
			psInsertSells.setInt(1,5); psInsertSells.setInt(2,1);
			psInsertSells.executeUpdate();
	
			psInsertSells.setInt(1,5); psInsertSells.setInt(2,2);
			psInsertSells.executeUpdate();
	
			psInsertSells.setInt(1,5); psInsertSells.setInt(2,3);
			psInsertSells.executeUpdate();

			con.commit(); // transaction ends here
		} catch(SQLException ex) {
			con.rollback(); // put databse in state before the transaction began
			System.err.println("SQLException: " + ex.getMessage());
			System.err.println("Database rolled back inserting Canadian Tire");
		}

		try {
			// transaction begins here
			// Note: Table SUPPLIER is indexed on SNO, so no duplicates are allowed
			psInsertSells.setInt(1,5); psInsertSells.setInt(2,10);
			psInsertSells.executeUpdate();
	
			psInsertSells.setInt(1,5); psInsertSells.setInt(2,20);
			psInsertSells.executeUpdate();

			psInsertSells.setInt(1,5); psInsertSells.setInt(2,30);
			psInsertSells.executeUpdate();

			psInsertSupplier.setInt(1,5);
			psInsertSupplier.setString(2,"Toronto");
			psInsertSupplier.setString(3,"Home Depot");
			psInsertSupplier.executeUpdate();

			con.commit(); // transaction ends here
		} catch(SQLException ex) {
			con.rollback(); // put database in state before transaction began
			System.err.println("SQLException: " + ex.getMessage());
			System.err.println("Database rolled back inserting Home Depot");
		}
		psInsertSupplier.close();
		psInsertSells.close();
		con.setAutoCommit(true); // Change to atomic-transaction mode.
	}
}
